

import React, { useState, useEffect } from "react";
import './index.css';
import axios from "axios";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faBell, faBars, faSearch, faSignOutAlt } from "@fortawesome/free-solid-svg-icons";
import image1 from "../../Assests/Images/logo.jpeg";
import image2 from "../../Assests/Images/man.png";
import { Link, useNavigate, useParams } from "react-router-dom";
import { toast } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";
import { Sidenav } from "../../Components/Sidenav";

export const Updateprofile = () => {
    const navigate = useNavigate();
    const { id } = useParams(); // This gets the user ID from the URL
    const [user, setUser] = useState(null);

    const [isModalOpen, setIsModalOpen] = useState(false);

    // Form fields
    const [name, setName] = useState('');
    const [email, setEmail] = useState('');
    const [phone, setPhone] = useState('');
    const [address, setAddress] = useState('');
    const [profession, setProfession] = useState('');
    const [image, setImage] = useState(null);
    const [existingImage, setExistingImage] = useState('');


    useEffect(() => {
        const storedUser = JSON.parse(localStorage.getItem("user"));
        if (storedUser) {
            setUser(storedUser);
            setName(storedUser.name || '');
            setEmail(storedUser.email || '');
            setPhone(storedUser.phone || '');
            setAddress(storedUser.address || '');
            setProfession(storedUser.profession || '');
            setExistingImage(storedUser.image || '');
        }
    }, []);


    useEffect(() => {
        const storedUser = JSON.parse(localStorage.getItem("user"));
        if (storedUser) {
            setUser(storedUser);
        }
    }, []);


    // const handleUpdateSubmit = async (e) => {
    //     e.preventDefault();
    //     if (!user) {
    //         toast.error('User not loaded!');
    //         return;
    //     }

    //     const formData = new FormData();
    //     formData.append('name', name);
    //     formData.append('email', email);
    //     formData.append('phone', phone);
    //     formData.append('address', address);
    //     formData.append('profession', profession);
    //     if (image) {
    //         formData.append('image', image);
    //     }
    //     formData.append('_method', 'PUT');

    //     try {
    //         const token = localStorage.getItem('token');
    //         const response = await axios.post(`http://localhost:8000/api/users/${user.id}`, formData, {
    //             headers: {
    //                 'Authorization': `Bearer ${token}`,
    //                 'Content-Type': 'multipart/form-data',
    //             },
    //         });

    //         if (response?.data?.success) {
    //             toast.success('Profile updated!');
    //             setIsModalOpen(false);
    //             // Optional: reload page or fetch user again
    //             window.location.reload();
    //         }
    //     } catch (error) {
    //         console.error(error);
    //         toast.error('Update failed!');
    //     }
    // };


    const handleUpdateSubmit = async (e) => {
        e.preventDefault();
        if (!user) {
            toast.error('User not loaded!');
            return;
        }
    
        const formData = new FormData();
        formData.append('name', name);
        formData.append('email', email);
        formData.append('phone', phone);
        formData.append('address', address);
        formData.append('profession', profession);
        if (image) {
            formData.append('image', image);
        }
        formData.append('_method', 'PUT');
    
        try {
            const token = localStorage.getItem('token');
            const response = await axios.post(`http://localhost:8000/api/users/${user.id}`, formData, {
                headers: {
                    'Authorization': `Bearer ${token}`,
                    'Content-Type': 'multipart/form-data',
                },
            });
    
            if (response?.data?.success) {
                const updatedUser = response.data.data;
            
                const updatedImagePath = updatedUser.image
                  ? `http://localhost:8000/${updatedUser.image}?${Date.now()}`
                  : existingImage;
            
                const finalUser = {
                    ...user,
                    name: updatedUser.name,
                    email: updatedUser.email,
                    phone: updatedUser.phone,
                    address: updatedUser.address,
                    profession: updatedUser.profession,
                    image: updatedImagePath,  // full image URL with cache busting
                };
            
                localStorage.setItem('user', JSON.stringify(finalUser));
                setUser(finalUser);
                setExistingImage(updatedImagePath);
                setIsModalOpen(false);
                toast.success('Profile updated!');
            }
            
        } catch (error) {
            console.error(error);
            toast.error('Update failed!');
        }
    };
    


    return (
        <div className="admin">
            <div className="admin-header">
                <div className="admin-header-img-bx">
                    <img src={image1} alt="Logo" />
                    <h1>RippleAid</h1>
                    <span className="menu-icon">
                        <FontAwesomeIcon icon={faBars} />
                    </span>
                </div>
                <div className="admin-header-serch-bx">
                    <form action="">
                        <input type="text" placeholder="Search" />
                        <button><FontAwesomeIcon icon={faSearch} /></button>
                    </form>
                </div>
                <div className="admin-header-user-bx">
                    <div className="admin-header-icon">
                        <span><FontAwesomeIcon icon={faBell} /></span>
                    </div>
                    {user ? (
                        <img src={user.image ? `http://localhost:8000/${user.image}` : "/default-avatar.png"} alt="User" />

                    ) : (
                        <img src={image2} alt="User" />
                    )}
                    <form action="" onSubmit={async (e) => {
                        e.preventDefault();
                        try {
                            const token = localStorage.getItem("token");
                            const response = await axios.post(
                                "http://localhost:8000/api/logout",
                                {},
                                { headers: { Authorization: `Bearer ${token}` } }
                            );

                            if (response?.data?.message === "Successfully logged out") {
                                localStorage.removeItem("token");
                                localStorage.removeItem("user");
                                window.location.href = "/login";
                            }
                        } catch (error) {
                            console.error("Error logging out:", error);
                        }
                    }}>
                        <button><FontAwesomeIcon icon={faSignOutAlt} /></button>
                    </form>
                </div>
            </div>

            <div className="admin-content">
                <Sidenav />
                <div className="admin-content-main">
                    <div className="my-card">
                        <div className="img-bx">
                        <img src={user.image ? `http://localhost:8000/${user.image}` : "/default-avatar.png"} alt="User" />


                        </div>
                        <div className="user-info">
                            <h2>{user ? user.name : "User"}</h2>
                            <p>{user ? user.email : "Email"}</p>
                            <p>{user ? user.phone : "Phone"}</p>
                            <p>{user ? user.address : "Address"}</p>
                            <p>{user ? user.profession : "Profession"}</p>
                        </div>
                    </div>

                    <button className="up-link" onClick={() => setIsModalOpen(true)}>
                        Update My Profile
                    </button>
                    {isModalOpen && (
                        <div className="modal-overlay">
                            <div className="modal">
                                <h2>Update Profile</h2>
                                <form onSubmit={handleUpdateSubmit}>
                                    <div className="form-group">
                                        <label>Name:</label>
                                        <input type="text" value={name} onChange={(e) => setName(e.target.value)} />
                                    </div>
                                    <div className="form-group">
                                        <label>Email:</label>
                                        <input type="email" value={email} onChange={(e) => setEmail(e.target.value)} />
                                    </div>
                                    <div className="form-group">
                                        <label>Phone:</label>
                                        <input type="text" value={phone} onChange={(e) => setPhone(e.target.value)} />
                                    </div>
                                    <div className="form-group">
                                        <label>Address:</label>
                                        <input type="text" value={address} onChange={(e) => setAddress(e.target.value)} />
                                    </div>
                                    <div className="form-group">
                                        <label>Profession:</label>
                                        <input type="text" value={profession} onChange={(e) => setProfession(e.target.value)} />
                                    </div>
                                    <div className="form-group">
                                        <label>Profile Image:</label>
                                        <input type="file" onChange={(e) => setImage(e.target.files[0])} />
                                        {existingImage && !image && <img src={`http://localhost:8000/${existingImage}`} alt="Existing" width="100" />}
                                        {image && <img src={URL.createObjectURL(image)} alt="New" width="100" />}
                                    </div>
                                    <div className="modal-buttons">
                                        <button type="button" onClick={() => setIsModalOpen(false)}>Cancel</button>
                                        <button type="submit">Update</button>
                                    </div>
                                </form>
                            </div>
                        </div>
                    )}



                </div>
            </div>
            <div className="admin-footer">
                <p>2021 RippleAid &copy; Copyright</p>
            </div>
        </div>
    );
};
